Add fullscreen support back in.
diff --git a/core/java/android/webkit/WebChromeClient.java b/core/java/android/webkit/WebChromeClient.java
index 19e39ed..dd43b8b 100644
--- a/core/java/android/webkit/WebChromeClient.java
+++ b/core/java/android/webkit/WebChromeClient.java
@@ -45,13 +45,29 @@
     public void onReceivedIcon(WebView view, Bitmap icon) {}
 
     /**
      * Notify the host application that the current page would
      * like to show a custom View.
      * @param view is the View object to be shown.
      *
      * @hide pending council approval
      */
-    public void onShowCustomView(View view) {}
+    public interface CustomViewCallback {
+        /**
+         * Invoked when the host application dismisses the
+         * custom view.
+         */
+        public void onCustomViewHidden();
+    }
+
+    /**
+     * Notify the host application that the current page would
+     * like to show a custom View.
+     * @param view is the View object to be shown.
+     * @param callback is the callback to be invoked if and when the view
+     * is dismissed.
+     *
+     * @hide pending council approval
+     */
+    public void onShowCustomView(View view, CustomViewCallback callback) {};
 
     /**
      * Notify the host application that the current page would
@@ -45,13 +45,29 @@
 
     /**
-     * Notify the host application that the current page would
-     * like to show a custom View.
-     * @param view is the View object to be shown.
+     * A callback interface used by the host application to notify
+     * the current page that its custom view has been dismissed.
      *
      * @hide pending council approval